/*
 * Copyright (C) 2013 - Gareth Llewellyn
 *
 * This file is part of the Unofficial HackedIO Android App https://github.com/NetworksAreMadeOfString/HackedIO-Android-App
 *
 * This app is unofficial. The "Hacked.io" logo is copyright (and maybe even a trademark of) Telefónica UK Limited.
 * The author of this app is not affiliated with Telefónica UK Limited, The Lab ( https://thelab.o2.com/ ) or
 * Geeks of London ( http://geeksoflondon.com/ ) although the author <strong>is</strong> an attendee.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>
 */
package app.hacked;

import android.content.Context;
import android.graphics.Typeface;
import android.text.Html;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.TextView;
import com.android.volley.RequestQueue;
import com.android.volley.toolbox.ImageLoader;
import com.android.volley.toolbox.NetworkImageView;
import com.android.volley.toolbox.Volley;

import java.util.List;

public class ChallengeListAdapter extends BaseAdapter
{

    private Context context;
    private List<ChallengeItem> HackedIOChallenges;
    private RequestQueue mRequestQueue;
    private ImageLoader mImageLoader;
    private String baseURL = "http://hacked.io";
    public ChallengeListAdapter(Context context, List<ChallengeItem> HackedIOChallenges)
    {
        this.context = context;
        this.HackedIOChallenges = HackedIOChallenges;
    }

    @Override
    public int getCount()
    {
       return HackedIOChallenges.size();
    }

    @Override
    public Object getItem(int i)
    {
        return HackedIOChallenges.get(i);
    }

    @Override
    public long getItemId(int i)
    {
        return i;
    }

    @Override
    public View getView(int position, View convertView, ViewGroup viewGroup)
    {
        ChallengeItem challengeItem = HackedIOChallenges.get(position);

        LayoutInflater inflater = (LayoutInflater) context.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
        convertView = inflater.inflate(R.layout.challenge_list_item, null);

        TextView title = ((TextView) convertView.findViewById(R.id.challengeTitle));

        title.setText(Html.fromHtml(challengeItem.ChallengeTitle));
        title.setTypeface(Typeface.create("sans-serif-light", Typeface.NORMAL));

        if(mRequestQueue == null)
        {
            mRequestQueue = Volley.newRequestQueue(this.context);
        }

        if(mImageLoader == null)
        {
            mImageLoader = new ImageLoader(mRequestQueue, new BitmapLruCache());
        }

        ((NetworkImageView) convertView.findViewById(R.id.challengeImage)).setImageUrl(baseURL + challengeItem.ChallengeImageURL ,mImageLoader);


        return convertView;
    }
}
