/*
 * Copyright (C) 2013 - Gareth Llewellyn
 *
 * This file is part of the Unofficial HackedIO Android App https://github.com/NetworksAreMadeOfString/HackedIO-Android-App
 *
 * This app is unofficial. The "Hacked.io" logo is copyright (and maybe even a trademark of) Telefónica UK Limited.
 * The author of this app is not affiliated with Telefónica UK Limited, The Lab ( https://thelab.o2.com/ ) or
 * Geeks of London ( http://geeksoflondon.com/ ) although the author <strong>is</strong> an attendee.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>
 */
package app.hacked;

import android.content.Context;
import android.graphics.Typeface;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.TextView;
import com.android.volley.RequestQueue;
import com.android.volley.toolbox.ImageLoader;
import com.android.volley.toolbox.NetworkImageView;
import com.android.volley.toolbox.Volley;

import java.util.ArrayList;
import java.util.List;

public class ChatAdapter extends BaseAdapter
{
    private Context context;
    public List<ChatMessage> ChatMessages;
    private RequestQueue mRequestQueue;
    private ImageLoader mImageLoader;
    private static String GRAVATAR_BASE = "http://www.gravatar.com/avatar/";
    private int mDimen = 72;

    public ChatAdapter(Context ctx, List<ChatMessage> Msgs)
    {
        this.context = ctx;
        this.ChatMessages = Msgs;

        mRequestQueue = Volley.newRequestQueue(ctx);
        mImageLoader = new ImageLoader(mRequestQueue, new BitmapLruCache());

        mDimen = (int) ctx.getResources().getDimension(R.dimen.AuthorHighlightSize);
    }

    public ChatAdapter(Context ctx)
    {
        this.context = ctx;
        this.ChatMessages = new ArrayList<ChatMessage>();
    }

    @Override
    public int getCount()
    {
        if(null != ChatMessages)
        {
            return ChatMessages.size();
        }
        else
        {
            return 0;
        }
    }

    @Override
    public Object getItem(int i)
    {
        return ChatMessages.get(i);
    }

    @Override
    public long getItemId(int i)
    {
        return i;
    }

    @Override
    public View getView(int i, View convertView, ViewGroup viewGroup)
    {
        ChatMessage chatMsg = ChatMessages.get(i);
        if (convertView == null)
        {
            LayoutInflater inflater = (LayoutInflater) context.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
            convertView = inflater.inflate(R.layout.chat_msg_simple, null);
        }

        ((TextView) convertView.findViewById(R.id.ChatMessage)).setText(chatMsg.Message);//chatMsg.Message
        ((TextView) convertView.findViewById(R.id.ChatMessage)).setTypeface(Typeface.create("sans-serif-light", Typeface.NORMAL));

        ((TextView) convertView.findViewById(R.id.ChatAuthor)).setText(chatMsg.getName());//chatMsg.Name
        ((TextView) convertView.findViewById(R.id.ChatAuthor)).setTypeface(Typeface.create("sans-serif-condensed", Typeface.BOLD));

        /*((TextView) convertView.findViewById(R.id.authorHighlight)).setText(chatMsg.Name.substring(0,1));
        ((TextView) convertView.findViewById(R.id.authorHighlight)).setTypeface(Typeface.create("sans-serif-light", Typeface.NORMAL));

        Random rnd = new Random();
        int color = Color.argb(255, rnd.nextInt(256), rnd.nextInt(256), rnd.nextInt(256));
        convertView.findViewById(R.id.authorHighlight).setBackgroundColor(color);*/

        if(mRequestQueue == null)
        {
            mRequestQueue = Volley.newRequestQueue(this.context);
        }

        if(mImageLoader == null)
        {
            mImageLoader = new ImageLoader(mRequestQueue, new BitmapLruCache());
        }

        ((NetworkImageView) convertView.findViewById(R.id.authorHighlight)).setImageUrl(GRAVATAR_BASE + chatMsg.getGravatar() + "?d=retro&s="+ Integer.toString(mDimen),mImageLoader);

        return convertView;
    }


}

