/*
 * Copyright (C) 2013 - Gareth Llewellyn
 *
 * This file is part of the Unofficial HackedIO Android App https://github.com/NetworksAreMadeOfString/HackedIO-Android-App
 *
 * This app is unofficial. The "Hacked.io" logo is copyright (and maybe even a trademark of) Telefónica UK Limited.
 * The author of this app is not affiliated with Telefónica UK Limited, The Lab ( https://thelab.o2.com/ ) or
 * Geeks of London ( http://geeksoflondon.com/ ) although the author <strong>is</strong> an attendee.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>
 */
package app.hacked;

import android.app.Activity;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.support.v4.app.ListFragment;
import android.util.Log;
import android.view.*;
import android.widget.ListView;
import android.widget.Toast;
import com.android.volley.Request;
import com.android.volley.RequestQueue;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.JsonObjectRequest;
import com.android.volley.toolbox.Volley;
import org.json.JSONArray;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.List;


public class ProjectListFragment extends ListFragment
{
    /*TrapListAdapter adapter = null;
    TrapsDataSource datasource = null;*/

    RequestQueue queue = null;

    public static final int ATTACHTYPE = 0;

    /**
     * A list of the times where Hacked.io events will be happening
     */
    public List<Project> HackedIOProjects = null;

    /**
     * The serialization (saved instance state) Bundle key representing the
     * activated item position. Only used on tablets.
     */
    private static final String STATE_ACTIVATED_POSITION = "activated_position";

    /**
     * The fragment's current callback object, which is notified of list item
     * clicks.
     */
    private Callbacks mCallbacks = sDummyCallbacks;

    /**
     * The current activated item position. Only used on tablets.
     */
    private int mActivatedPosition = ListView.INVALID_POSITION;

    private String mSelectedHost = null;

    /**
     *
     */
    ProjectListAdapter adapter = null;

    private View progressBar = null;

    /**
     * A callback interface that all activities containing this fragment must
     * implement. This mechanism allows activities to be notified of item
     * selections.
     */
    public interface Callbacks
    {
        /**
         * Callback for when an item has been selected.
         */
        public void onProjectItemSelected(Project project);
    }

    /**
     * A dummy implementation of the {@link Callbacks} interface that does
     * nothing. Used only when this fragment is not attached to an activity.
     */
    private static Callbacks sDummyCallbacks = new Callbacks()
    {
        @Override
        public void onProjectItemSelected(Project project)
        {
        }
    };

    /**
     * Mandatory empty constructor for the fragment manager to instantiate the
     * fragment (e.g. upon screen orientation changes).
     */
    public ProjectListFragment() {
    }

    /*@Override
    public void onStart()
    {
        super.onStart();
        getActivity().getActionBar().setIcon(R.drawable.projects_image);
    }*/

    @Override
    public void onCreate(Bundle savedInstanceState)
    {
        super.onCreate(savedInstanceState);
        queue = Volley.newRequestQueue(getActivity());

        getData();
    }


    private void getData()
    {
        if(null != progressBar)
            progressBar.setVisibility(View.VISIBLE);

        HackedIOProjects = new ArrayList<Project>();

        String url = "http://hackedioapp.networksaremadeofstring.co.uk/projects.php";

        JsonObjectRequest jsObjRequest = new JsonObjectRequest(Request.Method.GET, url, null, new Response.Listener<JSONObject>() {

            @Override
            public void onResponse(JSONObject response)
            {
                try
                {
                    if(response.has("success") && response.getBoolean("success") && response.has("projects"))
                    {
                        Log.e("response", response.toString());

                        JSONArray projects = response.getJSONArray("projects");
                        int size = projects.length();
                        for(int i = 0; i < size; i++)
                        {
                            JSONObject projectJSON = projects.getJSONObject(i);

                            HackedIOProjects.add(new Project(projectJSON));
                        }

                        if(null != progressBar)
                            progressBar.setVisibility(View.GONE);

                        adapter = new ProjectListAdapter(getActivity(),HackedIOProjects);

                        setListAdapter(adapter);
                    }
                    else
                    {
                        Toast.makeText(getActivity(),"An Error Was encountered",Toast.LENGTH_SHORT).show();
                    }
                }
                catch(Exception e)
                {
                    e.printStackTrace();
                    Toast.makeText(getActivity(),"An Error Was encountered",Toast.LENGTH_SHORT).show();
                }

            }
        }, new Response.ErrorListener() {

            @Override
            public void onErrorResponse(VolleyError error)
            {
                // TODO Auto-generated method stub
                Toast.makeText(getActivity(),"An Error Was encountered",Toast.LENGTH_SHORT).show();
            }
        });

        queue.add(jsObjRequest);
    }

    @Override
    public void onViewCreated(View view, Bundle savedInstanceState)
    {
        super.onViewCreated(view, savedInstanceState);

        // Restore the previously serialized activated item position.
        if (savedInstanceState != null && savedInstanceState.containsKey(STATE_ACTIVATED_POSITION))
        {
            setActivatedPosition(savedInstanceState.getInt(STATE_ACTIVATED_POSITION));
        }

        if (getActivity().findViewById(R.id.ProjectDetails) != null && savedInstanceState == null)
        {
            ProjectWelcomeFragment fragment = new ProjectWelcomeFragment();
            getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.ProjectDetails, fragment).commit();
        }

        progressBar = view.findViewById(R.id.progressBar);

        if(savedInstanceState != null)
            progressBar.setVisibility(View.GONE);
    }


    @Override
    public void onAttach(Activity activity)
    {
        super.onAttach(activity);

        // Activities containing this fragment must implement its callbacks.
        if (!(activity instanceof Callbacks))
        {
            throw new IllegalStateException("Activity must implement fragment's callbacks.");
        }

        mCallbacks = (Callbacks) activity;
    }

    @Override
    public void onDetach()
    {
        super.onDetach();

        // Reset the active callbacks interface to the dummy implementation.
        mCallbacks = sDummyCallbacks;
    }

    @Override
    public void onListItemClick(ListView listView, View view, int position, long id)
    {
        super.onListItemClick(listView, view, position, id);

        // Notify the active callbacks interface (the activity, if the
        // fragment is attached to one) that an item has been selected.
        //mCallbacks.onItemSelected(DummyContent.ITEMS.get(position).id);
        mCallbacks.onProjectItemSelected(HackedIOProjects.get(position));

        //We want to keep track of this for our own purposes
        mActivatedPosition = position;
        //mSelectedScheduleItem = HackedIOSchedule.get(position).Hostname;
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,  Bundle savedInstanceState)
    {
        View view = inflater.inflate(R.layout.project_list_fragment, null);

        return view;
    }

    @Override
    public void onSaveInstanceState(Bundle outState)
    {
        super.onSaveInstanceState(outState);

        if (mActivatedPosition != ListView.INVALID_POSITION)
        {
            // Serialize and persist the activated item position.
            outState.putInt(STATE_ACTIVATED_POSITION, mActivatedPosition);
        }
    }

    /**
     * Turns on activate-on-click mode. When this mode is on, list items will be
     * given the 'activated' state when touched.
     */
    public void setActivateOnItemClick(boolean activateOnItemClick)
    {
        // When setting CHOICE_MODE_SINGLE, ListView will automatically
        // give items the 'activated' state when touched.
        getListView().setChoiceMode(activateOnItemClick ? ListView.CHOICE_MODE_SINGLE : ListView.CHOICE_MODE_NONE);
    }

    private void setActivatedPosition(int position)
    {
        if (position == ListView.INVALID_POSITION)
        {
            getListView().setItemChecked(mActivatedPosition, false);
        }
        else
        {
            getListView().setItemChecked(position, true);
        }

        mActivatedPosition = position;
    }

    @Override
    public void onCreateOptionsMenu(final Menu menu, final MenuInflater inflater)
    {
        inflater.inflate(R.menu.projects, menu);
        super.onCreateOptionsMenu(menu, inflater);
    }

    /**
     *
     */
    public void LaunchAddProject()
    {
        if (getActivity().findViewById(R.id.ProjectDetails) != null)
        {
            AddProjectFragment fragment = new AddProjectFragment();
            getActivity().getSupportFragmentManager().beginTransaction().replace(R.id.ProjectDetails, fragment).commit();
        }
        else
        {
            Intent addProjectIntent = new Intent(getActivity(), AddProjectActivity.class);
            startActivity(addProjectIntent);
        }
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item)
    {
        switch (item.getItemId())
        {
            case R.id.action_add_project:
            {
                //LaunchAddProject();
                startActivity(new Intent(Intent.ACTION_VIEW, Uri.parse("https://www.hackerleague.org/hackathons/hacked/hacks")));
                return true;
            }

            default:
                return false;

        }
    }
}
